@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -7,19 +7,19 @@
 #include "gravatardownloadpixmapwidget.h"
 #include "gravatar/gravatarresolvurljob.h"
 #include "gravatar_debug.h"
-#include <QLabel>
 #include <KLocalizedString>
-#include <QVBoxLayout>
+#include <QCheckBox>
+#include <QLabel>
 #include <QLineEdit>
 #include <QPushButton>
-#include <QCheckBox>
+#include <QVBoxLayout>
 
 using namespace Gravatar;
 GravatarDownloadPixmapWidget::GravatarDownloadPixmapWidget(QWidget *parent)
     : QWidget(parent)
 {
-    auto *mainLayout = new QVBoxLayout(this);
-    auto *hbox = new QHBoxLayout;
+    auto mainLayout = new QVBoxLayout(this);
+    auto hbox = new QHBoxLayout;
     mainLayout->addLayout(hbox);
     QLabel *lab = new QLabel(i18n("Email:"));
     lab->setObjectName(QStringLiteral("labemail"));
@@ -77,10 +77,10 @@ void GravatarDownloadPixmapWidget::slotResolvUrlFinish(Gravatar::GravatarResolvU
 void GravatarDownloadPixmapWidget::slotSearchButton()
 {
     mResultLabel->setText(QString());
-    auto *job = new Gravatar::GravatarResolvUrlJob(this);
+    auto job = new Gravatar::GravatarResolvUrlJob(this);
     job->setEmail(mLineEdit->text());
-    //For testing
-    //job->setUseDefaultPixmap(true);
+    // For testing
+    // job->setUseDefaultPixmap(true);
     job->setUseLibravatar(mUseLibravatar->isChecked());
     job->setFallbackGravatar(mFallbackGravatar->isChecked());
     if (job->canStart()) {
