@@ -1,19 +1,19 @@
 /*
-   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef GRAVATARDOWNLOADPIXMAPWIDGET_H
-#define GRAVATARDOWNLOADPIXMAPWIDGET_H
+#pragma once
 
-#include <QWidget>
 #include "gravatar_export.h"
+#include <QWidget>
 class QLabel;
 class QLineEdit;
 class QPushButton;
 class QCheckBox;
-namespace Gravatar {
+namespace Gravatar
+{
 class GravatarResolvUrlJob;
 
 /** Avatar download widget. */
@@ -22,7 +22,7 @@ class GRAVATAR_EXPORT GravatarDownloadPixmapWidget : public QWidget
     Q_OBJECT
 public:
     explicit GravatarDownloadPixmapWidget(QWidget *parent = nullptr);
-    ~GravatarDownloadPixmapWidget();
+    ~GravatarDownloadPixmapWidget() override;
 
     Q_REQUIRED_RESULT QPixmap gravatarPixmap() const;
 
@@ -40,4 +40,3 @@ private:
 };
 }
 
-#endif // GRAVATARDOWNLOADPIXMAPWIDGET_H
